@@ -26,12 +26,11 @@ from hspylib.core.tools.commons import str_to_bool
 def integration_test(cls: type):
     """Enable/Disable HsPyLib integration tests"""
 
-    it_disabled = str_to_bool(os.environ.get('HSPYLIB_IT_DISABLED', 'True'))
+    it_disabled = str_to_bool(os.environ.get("HSPYLIB_IT_DISABLED", "True"))
     if it_disabled:
-        log.debug('Skipping test: %s', cls.__name__)
+        log.debug("Skipping test: %s", cls.__name__)
         return unittest.skipIf(
-            it_disabled,
-            f'Disabled = {it_disabled} :integration tests because it needs real servers running'
+            it_disabled, f"Disabled = {it_disabled} :integration tests because it needs real servers running"
         )
 
     return cls
@@ -42,7 +41,7 @@ def temporized(func: Callable):
 
     def timedelta_to_str(delta: timedelta) -> str:
         """Convert timedelta object into string"""
-        parts = str(delta).split(':')
+        parts = str(delta).split(":")
         h, m, s = parts[0], parts[1], parts[2][:-7]
         ms = int(ceil(int(parts[2][-6:]) / 1000))
         return f"{h:02s}[h] {m:02s}[m] {s:02s}[s] {ms:02d}[ms]"
@@ -51,9 +50,7 @@ def temporized(func: Callable):
         """Execute the callable and return"""
         start = datetime.now()
         ret = func(*args)
-        log.debug(
-            "@@@ [%s] Time elapsed\t%s",
-            func.__name__, timedelta_to_str(datetime.now() - start))
+        log.debug("@@@ [%s] Time elapsed\t%s", func.__name__, timedelta_to_str(datetime.now() - start))
         return ret
 
     return temporized_closure
