@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: main.modules.cli.icons.font_awesome
+   @package: hspylib.modules.cli.icons.font_awesome
       @file: dashboard_icons.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -12,6 +12,8 @@
 
    Copyright 2022, HSPyLib team
 """
+from enum import auto
+
 from hspylib.modules.cli.icons.font_awesome.awesome import Awesome
 
 
@@ -23,6 +25,7 @@ class DashboardIcons(Awesome):
     """
 
     # fmt: off
+    _CUSTOM         = auto()
     ADJUSTMENTS     = '\uF1DE'  # 
     AGENDA          = '\uF073'  # 
     ALERT           = '\uF071'  # 
